@@ -256,6 +256,9 @@ class EducPlan(Base):
     edu_level = relationship('EduLevel')
     year = Column('educ_plan_adm_year', Integer)
 
+    # Статус
+    status = Column(Integer)
+
     def __repr__(self):
         return "<EducPlan {} {}>".format(self.speciality, self.year)
     
@@ -278,6 +281,9 @@ class EducPlanPos(Base):
     educ_plan_id = Column('educ_plan_id', ForeignKey('univer_educ_plan.educ_plan_id'))
     educ_plan = relationship('EducPlan')
 
+    # Код дисциплины
+    code = Column('rup_ru', String(50))
+
     # Дисциплина
     subject_id = Column('subject_id', ForeignKey('univer_subject.subject_id'))
     subject = relationship('Subject')
@@ -289,6 +295,9 @@ class EducPlanPos(Base):
     # Семестр
     semester = Column('educ_plan_pos_semestr', Integer)
 
+    # Статус
+    status = Column(Integer)
+
     def __repr__(self):
         return "<EducPlanPos {}: {} ({} семестр)>".format(self.educ_plan, self.subject, self.semester)
     
